package
module
Version:
v1.0.1
Opens a new window with list of versions in this module.
Published: Dec 19, 2021
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 15
Opens a new window with list of known importers.
README
¶
zdpgo_log
Golang日志框架
一、快速入门
1.1 创建日志并记录
package main
import "github.com/zhangdapeng520/zdpgo_log"
func main() {
log := zdpgo_log.New("zdpgo_log.log")
log.Debug = true // 开启debug模式
log.Info("info...")
log.Warning("warning...")
log.Error("error...")
log.Debug = false // 关闭debug模式
log.Info("info 111...")
log.Warning("warning 111...")
log.Error("error 111...")
}
Documentation
¶
func (log *Log) Error(args ...interface{})
记录error类型的日志
func (log *Log) Info(args ...interface{})
记录info类型的日志
func (log *Log) Warning(args ...interface{})
记录warning类型的日志
Source Files
¶
Directories
¶
examples
|
|
|
|
|
Click to show internal directories.
Click to hide internal directories.