package
module
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Dec 6, 2021
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 15
Opens a new window with list of known importers.
Documentation
¶
func (logger *Logger) Error(args ...interface{})
记录error类型的日志
func (logger *Logger) Info(args ...interface{})
记录info类型的日志
func (logger *Logger) Warning(args ...interface{})
记录warning类型的日志
Source Files
¶
Click to show internal directories.
Click to hide internal directories.